OiRA

Help

1. Preparation
2. Involve
3. Identification + Evaluation
   1. 1 Commercial manned guarding
   2. Ω Other risks
      1. Ω.1 The entrance floor is often wet
   - Unanswered
   - Postponed
   - No risk
   - Risk identified
4. Action Plan
5. Report
6. Status 0%

In case you didn't find a risk that you have identified in your company, you are able to add it to your own risk assessment now:

Important: In order to avoid duplicating risks, we strongly recommend you to go first through all the previous modules, if you have not done it yet.

If you don't need to add risks, please continue.

Previous Continue to action plan

Scroll to top
Back

## other-risks.html

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More